package com.lzmispt.data.resource.service.monitor.impl;

package .tmp;

import com.lzmispt.core.dao.database.impl.BaseDaoImpl;
import com.lzmispt.core.entity.dto.authorize.UserInfoDTO;
import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.entity.vo.user.UserVO;
import com.lzmispt.data.center.entity.dto.log.CommonLogDTO;
import com.lzmispt.data.center.entity.dto.resource.lzdpdevelop.GetTableTreeDTO;
import com.lzmispt.data.center.entity.enums.StatusCodeEnum;
import com.lzmispt.data.center.entity.vo.resource.lzdpdevelop.TableTreeVO;
import com.lzmispt.data.resource.client.CoreClient;
import com.lzmispt.data.resource.client.DataApplyClient;
import com.lzmispt.data.resource.client.DataInterfaceClient;
import com.lzmispt.data.resource.dao.monitor.IMonitoringPlatformDao;
import com.lzmispt.data.resource.entity.dto.monitor.DragDataTableDTO;
import com.lzmispt.data.resource.entity.dto.monitor.GetDataTableDTO;
import com.lzmispt.data.resource.entity.dto.monitor.MonitorQueryDTO;
import com.lzmispt.data.resource.entity.dto.monitor.SaveWarningAndServerMonitorDTO;
import com.lzmispt.data.resource.entity.dto.monitor.SaveWarningRecipientDTO;
import com.lzmispt.data.resource.entity.dto.monitor.TableTreeDTO;
import com.lzmispt.data.resource.entity.po.monitor.DataPushMonitorPO;
import com.lzmispt.data.resource.entity.po.monitor.InterfaceInvokeDetailPO;
import com.lzmispt.data.resource.entity.po.monitor.InterfaceInvokeRecordPO;
import com.lzmispt.data.resource.entity.po.monitor.InterfaceServiceMonitorPO;
import com.lzmispt.data.resource.entity.po.monitor.ResourceMonitorPO;
import com.lzmispt.data.resource.entity.po.monitor.ServerMonitorPO;
import com.lzmispt.data.resource.entity.po.monitor.TableStatisticsPO;
import com.lzmispt.data.resource.entity.po.monitor.WarningRecipientPO;
import com.lzmispt.data.resource.entity.vo.monitor.DataPushMonitorVo;
import com.lzmispt.data.resource.entity.vo.monitor.InterfaceInvokeDetailVO;
import com.lzmispt.data.resource.entity.vo.monitor.InterfaceInvokeRecordVO;
import com.lzmispt.data.resource.entity.vo.monitor.InterfaceServiceMonitorVO;
import com.lzmispt.data.resource.entity.vo.monitor.MonitorDataVO;
import com.lzmispt.data.resource.entity.vo.monitor.ResourceMonitorVO;
import com.lzmispt.data.resource.entity.vo.monitor.ServerMonitorVO;
import com.lzmispt.data.resource.entity.vo.monitor.TableStatisticsVO;
import com.lzmispt.data.resource.entity.vo.monitor.WarningRecipientVo;
import com.lzmispt.data.resource.service.lzdpdevelop.ILZDPApi;
import com.lzmispt.data.resource.service.lzdpdevelop.impl.LzdpConfig;
import com.lzmispt.data.resource.service.monitor.IMonitoringPlatformService;
import com.lzmispt.data.resource.service.monitor.IPlatCommonDataQueryService;
import com.lzmispt.data.resource.service.monitor.IQuartzJobService;
import com.lzmispt.dcbase.ServiceUtil;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.dcbase.log.CommonLogHelper;
import com.lzmispt.dcbase.util.HeaderInterceptor;
import com.lzmispt.dcbase.util.TokenUtil;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.exception.ExceptionUtil;
import com.lzmispt.framework.fconst.FrameConst;
import com.lzmispt.framework.log.LogHelper;
import com.lzmispt.framework.utils.RabbitMQUtil;
import com.lzmispt.framework.utils.WorkerId;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import javax.annotation.PostConstruct;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;

@Service
public class MonitoringPlatformServiceImpl implements IMonitoringPlatformService {
  @Autowired
  BaseDaoImpl baseDaoImpl;
  
  @Autowired
  CoreClient coreClient;
  
  @Autowired
  DataInterfaceClient dataInterfaceClient;
  
  @Autowired
  DataApplyClient dataApplyClient;
  
  @Autowired
  IQuartzJobService quartzJobService;
  
  @Autowired
  ILZDPApi ilzdpApi;
  
  @Autowired
  LzdpConfig lzdpConfig;
  
  @Autowired
  IMonitoringPlatformDao iMonitoringPlatformDao;
  
  Map<Integer, IPlatCommonDataQueryService> tableTypeMap;
  
  @Autowired
  ApplicationContext applicationContext;
  
  private static Integer COUNT = Integer.valueOf(0);
  
  private static Integer DISKUNIT = Integer.valueOf(1024);
  
  public String getDefaultCode() {
    return "Statistics";
  }
  
  public ResultEntity<List<WarningRecipientVo>> getWarningRecipientList(String platCode, String tokenId) {
    List<WarningRecipientVo> result = new ArrayList<>();
    List<WarningRecipientPO> warningRecipientPoList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(platCode, IMonitoringPlatformDao.class)).getWarningRecipientList();
    if (!ObjectUtils.isEmpty(warningRecipientPoList))
      result = (List<WarningRecipientVo>)warningRecipientPoList.stream().map(warningRecipientPo -> {
            WarningRecipientVo warningRecipientVo = new WarningRecipientVo();
            BeanUtils.copyProperties(warningRecipientPo, warningRecipientVo);
            String userName = getUserName(warningRecipientPo.getUserId(), tokenId, new QueryModelDTO());
            warningRecipientVo.setUserName(userName);
            warningRecipientVo.setMangerUserId(warningRecipientPo.getUserId());
            return warningRecipientVo;
          }).collect(Collectors.toList()); 
    return ResultEntity.successMessage(result);
  }
  
  public ResultEntity saveMonitoringHomeConfiguration(SaveWarningAndServerMonitorDTO saveWarningRecipientDTOList, String token) {
    if (ObjectUtils.isEmpty(saveWarningRecipientDTOList))
      return ResultEntity.successMessage(saveWarningRecipientDTOList); 
    try {
      saveWarningRecipients(saveWarningRecipientDTOList);
      saveServerMonitorList(saveWarningRecipientDTOList, token);
      saveDataTable(saveWarningRecipientDTOList, token);
      updateSupportBusinessSystem(saveWarningRecipientDTOList);
      return ResultEntity.successMessage(saveWarningRecipientDTOList);
    } catch (Exception e) {
      LogHelper.error("保持服务器配置失败，具体错误信息：" + ExceptionUtil.getStackTraceMsg(e));
      return ResultEntity.errorMessage(Integer.valueOf(StatusCodeEnum.DATA_MONITOR_SAVE_CONFIG_FAILED.getCode()), StatusCodeEnum.DATA_MONITOR_SAVE_CONFIG_FAILED.getMessage());
    } 
  }
  
  private void saveWarningRecipients(SaveWarningAndServerMonitorDTO saveWarningRecipientDTOList) throws Exception {
    boolean result = saveWarningRecipients(saveWarningRecipientDTOList.getWarningRecipientList()).booleanValue();
    if (!result)
      throw new Exception(StatusCodeEnum.DATA_MONITOR_CANCEL_SAVE_WARNING_RECIPIENT_FAILED.getMessage()); 
  }
  
  private void saveServerMonitorList(SaveWarningAndServerMonitorDTO saveWarningRecipientDTOList, String token) throws Exception {
    if (ObjectUtils.isEmpty(saveWarningRecipientDTOList))
      return; 
    boolean result = saveServerMonitorList(saveWarningRecipientDTOList.getMonitorVOList(), token).booleanValue();
    if (!result)
      throw new Exception(StatusCodeEnum.DATA_MONITOR_CANCEL_SAVE_WARNING_RECIPIENT_FAILED.getMessage()); 
  }
  
  private void saveDataTable(SaveWarningAndServerMonitorDTO saveWarningRecipientDTOList, String token) throws Exception {
    if (ObjectUtils.isEmpty(saveWarningRecipientDTOList))
      return; 
    boolean result = saveDataTable(saveWarningRecipientDTOList.getTableStatisticsList(), token, saveWarningRecipientDTOList.getRes()).booleanValue();
    if (!result)
      throw new Exception(StatusCodeEnum.DATA_MONITOR_CANCEL_SAVE_DATA_TABLE_FAILED.getMessage()); 
  }
  
  private void updateSupportBusinessSystem(SaveWarningAndServerMonitorDTO saveWarningRecipientDTOList) throws Exception {
    if (ObjectUtils.isEmpty(saveWarningRecipientDTOList))
      return; 
    boolean result = updateSupportBusinessSystem(saveWarningRecipientDTOList.getSupportBusinessSystem()).booleanValue();
    if (!result)
      throw new Exception(StatusCodeEnum.DATA_MONITOR_CANCEL_SAVE_WARNING_RECIPIENT_FAILED.getMessage()); 
  }
  
  public Boolean saveServerMonitorList(List<ServerMonitorVO> monitorVOList, String token) {
    try {
      Boolean deleteCount = Boolean.valueOf(true);
      Boolean updateCount = Boolean.valueOf(true);
      Boolean insertCount = Boolean.valueOf(true);
      List<ServerMonitorPO> dbData = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(null, IMonitoringPlatformDao.class)).getServerMonitor();
      if (CollectionUtils.isEmpty(monitorVOList)) {
        ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).deleteServerMonitorAll();
        return deleteCount;
      } 
      if (CollectionUtils.isEmpty(dbData)) {
        for (ServerMonitorVO serverMonitorVO : monitorVOList) {
          ServerMonitorPO serverMonitorPO = new ServerMonitorPO();
          BeanUtils.copyProperties(serverMonitorVO, serverMonitorPO);
          serverMonitorPO.setId((Long)WorkerId.getNextId(Long.class));
          serverMonitorPO.setCreateTime(new Date());
          serverMonitorPO.setUpdateTime(new Date());
          serverMonitorPO.setTimingCron("0/3 * * * * ? ");
          serverMonitorPO.setIsDelete(Integer.valueOf(0));
          insertCount = Boolean.valueOf(this.baseDaoImpl.save(serverMonitorPO));
        } 
      } else {
        Map<Long, ServerMonitorPO> serverMonitorMap = new HashMap<>();
        for (ServerMonitorPO dbDatum : dbData)
          serverMonitorMap.put(dbDatum.getId(), dbDatum); 
        for (ServerMonitorVO serverMonitorVO : monitorVOList) {
          Long id = serverMonitorVO.getId();
          if (id == null || !serverMonitorMap.containsKey(id)) {
            ServerMonitorPO serverMonitorPO = new ServerMonitorPO();
            BeanUtils.copyProperties(serverMonitorVO, serverMonitorPO);
            serverMonitorPO.setId((Long)WorkerId.getNextId(Long.class));
            serverMonitorPO.setCreateTime(new Date());
            serverMonitorPO.setUpdateTime(new Date());
            serverMonitorPO.setTimingCron("0/3 * * * * ? ");
            serverMonitorPO.setIsDelete(Integer.valueOf(0));
            this.baseDaoImpl.save(serverMonitorPO);
          } else {
            ServerMonitorPO updateServerMonitor = new ServerMonitorPO();
            BeanUtils.copyProperties(serverMonitorVO, updateServerMonitor);
            ServerMonitorPO mapServerMonitorPO = serverMonitorMap.get(id);
            if (!updateServerMonitor.equals(mapServerMonitorPO)) {
              if (StringUtils.isEmpty(serverMonitorVO.getPassword()))
                updateServerMonitor.setPassword(mapServerMonitorPO.getPassword()); 
              updateServerMonitor.setUpdateTime(new Date());
              updateServerMonitor.setIsDelete(Integer.valueOf(0));
              updateCount = Boolean.valueOf(this.baseDaoImpl.update(updateServerMonitor));
            } 
          } 
          serverMonitorMap.remove(id);
        } 
        for (ServerMonitorPO value : serverMonitorMap.values())
          deleteCount = Boolean.valueOf(this.baseDaoImpl.delete(value.getId(), ServerMonitorPO.class)); 
      } 
      return Boolean.valueOf((insertCount.booleanValue() && deleteCount.booleanValue() && updateCount.booleanValue()));
    } catch (BeansException e) {
      LogHelper.error("save serverMonitor failure, Specific information：" + ExceptionUtil.getStackTraceMsg((Exception)e));
      return Boolean.valueOf(false);
    } 
  }
  
  public Boolean updateSupportBusinessSystem(Integer supportBusinessSystem) {
    ResourceMonitorPO resourceMonitor = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getResourceMonitor();
    if (resourceMonitor.getBusinessSystemCount().intValue() == supportBusinessSystem.intValue())
      return Boolean.valueOf(true); 
    Integer flag = Integer.valueOf(0);
    if (!ObjectUtils.isEmpty(resourceMonitor)) {
      resourceMonitor.setBusinessSystemCount(Integer.valueOf(supportBusinessSystem.intValue()));
      flag = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).updateSupportBusinessSystem(resourceMonitor);
    } 
    return Boolean.valueOf((flag.intValue() > 0));
  }
  
  public Boolean saveDataTable(List<TableStatisticsVO> tableStatisticsList, String token, Integer res) {
    Integer insertCount = Integer.valueOf(0);
    Integer deleteCount = Integer.valueOf(0);
    List<TableStatisticsPO> dbData = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getTableStatisticsList();
    if (CollectionUtils.isEmpty(tableStatisticsList) && !CollectionUtils.isEmpty(dbData)) {
      deleteCount = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(null, IMonitoringPlatformDao.class)).batchDataTableByIds(dbData);
      return Boolean.valueOf(deleteCount.equals(Integer.valueOf(dbData.size())));
    } 
    tableStatisticsList.forEach(vo -> {
          Integer plateCode = getTablePlateCode(vo.getTableId());
          if ("Apply".equals(getCode(plateCode))) {
            vo.setTableId(splitStringApply(vo.getTableId()));
          } else {
            vo.setTableId(splitString(vo.getTableId()));
          } 
          vo.setTablePlatCode(plateCode);
        });
    List<String> dbIds = (List<String>)dbData.stream().map(TableStatisticsPO::getTableId).collect(Collectors.toList());
    List<String> paramDataIds = (List<String>)tableStatisticsList.stream().map(TableStatisticsVO::getTableId).collect(Collectors.toList());
    List<TableStatisticsPO> insertData = (List<TableStatisticsPO>)tableStatisticsList.stream().filter(dto -> !dbIds.contains(dto.getTableId())).map(dto -> {
          int order = dbData.size();
          TableStatisticsPO tableStatisticsPO = new TableStatisticsPO();
          BeanUtils.copyProperties(dto, tableStatisticsPO);
          UserInfoDTO userInfo = TokenUtil.getUserInfoByTokenId(token);
          tableStatisticsPO.setDataCount(Integer.valueOf(0));
          tableStatisticsPO.setIsShow(Integer.valueOf(1));
          tableStatisticsPO.setTablePlatCode(dto.getTablePlatCode());
          if (tableStatisticsPO.getTablePlatCode().intValue() != Integer.parseInt(DCConst.PlatInt.APPLY))
            tableStatisticsPO.setTableId(splitString(tableStatisticsPO.getTableId())); 
          tableStatisticsPO.setOrder(Integer.valueOf(order++));
          tableStatisticsPO.setUserId(userInfo.getUserId());
          tableStatisticsPO.setOrgId(userInfo.getOrganizationId());
          tableStatisticsPO.setIsDelete(DCConst.FALSE);
          tableStatisticsPO.setCreateTime(new Date());
          tableStatisticsPO.setUpdateTime(new Date());
          return tableStatisticsPO;
        }).collect(Collectors.toList());
    List<TableStatisticsPO> deleteData = (List<TableStatisticsPO>)dbData.stream().filter(po -> !paramDataIds.contains(po.getTableId())).collect(Collectors.toList());
    if (!insertData.isEmpty()) {
      insertCount = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(null, IMonitoringPlatformDao.class)).batchSaveDataTable(insertData);
      this.quartzJobService.updateInsertDataTable(insertData, res, token);
    } 
    if (!deleteData.isEmpty())
      deleteCount = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(null, IMonitoringPlatformDao.class)).batchDataTableByIds(deleteData); 
    updateCode(tableStatisticsList);
    return Boolean.valueOf((insertCount.equals(Integer.valueOf(insertData.size())) && deleteCount.equals(Integer.valueOf(deleteData.size()))));
  }
  
  private void updateCode(List<TableStatisticsVO> tableStatisticsList) {
    int order = 1;
    for (TableStatisticsVO tableStatisticsVO : tableStatisticsList) {
      TableStatisticsPO tableStatisticsPO = new TableStatisticsPO();
      BeanUtils.copyProperties(tableStatisticsVO, tableStatisticsPO);
      tableStatisticsPO.setUpdateTime(new Date());
      tableStatisticsPO.setOrder(Integer.valueOf(order++));
      this.iMonitoringPlatformDao.dragDataTable(tableStatisticsPO);
    } 
  }
  
  private Integer getTablePlateCode(String tableId) {
    String[] s = tableId.split("_");
    String code = s[0];
    if ("Collection".equals(code))
      return Integer.valueOf(0); 
    if ("Manage".equals(code))
      return Integer.valueOf(1); 
    if ("Apply".equals(code))
      return Integer.valueOf(2); 
    return null;
  }
  
  private String splitStringApply(String tableId) {
    String[] s = tableId.split("_");
    return s[1] + s[2];
  }
  
  private String splitString(String tableId) {
    if (StringUtils.isEmpty(tableId))
      return ""; 
    String[] s = tableId.split("_");
    String code = s[0];
    if (code.equals("Apply"))
      return splitStringApply(tableId); 
    return s[s.length - 1];
  }
  
  public Boolean saveWarningRecipients(List<SaveWarningRecipientDTO> warningRecipientList) {
    try {
      List<WarningRecipientPO> dbData = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(null, IMonitoringPlatformDao.class)).getWarningRecipientList();
      Boolean deleteCount = Boolean.valueOf(true);
      Boolean insertCount = Boolean.valueOf(true);
      if (CollectionUtils.isEmpty(warningRecipientList) && !CollectionUtils.isEmpty(dbData)) {
        for (WarningRecipientPO dbDatum : dbData)
          deleteCount = Boolean.valueOf(this.baseDaoImpl.delete(dbDatum.getId(), WarningRecipientPO.class)); 
        return deleteCount;
      } 
      if (CollectionUtils.isEmpty(dbData)) {
        List<WarningRecipientPO> insertData = (List<WarningRecipientPO>)warningRecipientList.stream().map(saveWarningRecipientDTO -> {
              WarningRecipientPO warningRecipientPO = new WarningRecipientPO();
              BeanUtils.copyProperties(saveWarningRecipientDTO, warningRecipientPO);
              warningRecipientPO.setId((Long)WorkerId.getNextId(Long.class));
              warningRecipientPO.setUpdateTime(new Date());
              warningRecipientPO.setCreateTime(new Date());
              warningRecipientPO.setIsDelete(Integer.valueOf(0));
              warningRecipientPO.setParticipationOrgId(saveWarningRecipientDTO.getParticipationOrgId());
              warningRecipientPO.setUserId(saveWarningRecipientDTO.getMangerUserId());
              return warningRecipientPO;
            }).collect(Collectors.toList());
        for (WarningRecipientPO insertDatum : insertData)
          insertCount = Boolean.valueOf(this.baseDaoImpl.save(insertDatum)); 
      } else {
        Map<Long, WarningRecipientPO> warningRecipientMap = new HashMap<>();
        for (WarningRecipientPO dbDatum : dbData)
          warningRecipientMap.put(dbDatum.getId(), dbDatum); 
        for (SaveWarningRecipientDTO warningRecipient : warningRecipientList) {
          Long id = warningRecipient.getId();
          if (id == null || !warningRecipientMap.containsKey(id)) {
            WarningRecipientPO warningRecipientPO = new WarningRecipientPO();
            BeanUtils.copyProperties(warningRecipient, warningRecipientPO);
            warningRecipientPO.setId((Long)WorkerId.getNextId(Long.class));
            warningRecipientPO.setUserId(warningRecipient.getMangerUserId());
            warningRecipientPO.setUpdateTime(new Date());
            warningRecipientPO.setCreateTime(new Date());
            warningRecipientPO.setIsDelete(Integer.valueOf(0));
            insertCount = Boolean.valueOf(this.baseDaoImpl.save(warningRecipientPO));
          } 
          warningRecipientMap.remove(id);
        } 
        for (WarningRecipientPO value : warningRecipientMap.values())
          deleteCount = Boolean.valueOf(this.baseDaoImpl.delete(value.getId(), WarningRecipientPO.class)); 
      } 
      return Boolean.valueOf((deleteCount.booleanValue() && insertCount.booleanValue()));
    } catch (BeansException e) {
      LogHelper.error("save WarningRecipient error, Specific information：" + ExceptionUtil.getStackTraceMsg((Exception)e));
      return Boolean.valueOf(false);
    } 
  }
  
  public ResultEntity<ResourceMonitorVO> getResourceMonitor(String unit, Long dirId) {
    ResourceMonitorPO resourceMonitorPO = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getResourceMonitor(dirId, null, null);
    ResourceMonitorVO resourceMonitorVO = new ResourceMonitorVO();
    if (!ObjectUtils.isEmpty(resourceMonitorPO)) {
      BeanUtils.copyProperties(resourceMonitorPO, resourceMonitorVO);
      resourceMonitorVO.setBusinessSystemCount(resourceMonitorPO.getBusinessSystemCount() + "个");
      resourceMonitorVO.setTotalDataCount(resourceMonitorPO.getTotalDataCount() + "条");
      resourceMonitorVO.setTodayCollectionCount(resourceMonitorPO.getTodayCollectionCount() + "条");
      if (resourceMonitorPO.getTodayCollectionFileCount() == null)
        resourceMonitorPO.setTodayCollectionFileCount(Long.valueOf(0L)); 
      if (resourceMonitorPO.getPlatFileCount() == null)
        resourceMonitorPO.setPlatFileCount(Long.valueOf(0L)); 
      if (resourceMonitorPO.getCodeTableCount() == null)
        resourceMonitorPO.setCodeTableCount(Integer.valueOf(0)); 
      if (resourceMonitorPO.getDataDiskSpace() == null)
        resourceMonitorPO.setDataDiskSpace(Long.valueOf(0L)); 
      if (resourceMonitorPO.getManagePlatDataDiskSpace() == null)
        resourceMonitorPO.setManagePlatDataDiskSpace(Long.valueOf(0L)); 
      resourceMonitorVO.setTodayCollectionFileCount(resourceMonitorPO.getTodayCollectionFileCount() + "条");
      resourceMonitorVO.setPlatFileCount(resourceMonitorPO.getPlatFileCount() + "条");
      resourceMonitorVO.setCodeTableCount(resourceMonitorPO.getCodeTableCount() + "个");
      resourceMonitorVO.setDataDiskSpace(getDiskSpaceStr(resourceMonitorPO.getDataDiskSpace(), unit));
      resourceMonitorVO.setManagePlatDataDiskSpace(getDiskSpaceStr(resourceMonitorPO.getManagePlatDataDiskSpace(), unit));
    } else {
      resourceMonitorVO.setBusinessSystemCount("0个");
      resourceMonitorVO.setTotalDataCount("0条");
      resourceMonitorVO.setTodayCollectionCount("0条");
      resourceMonitorVO.setTodayCollectionFileCount("0条");
      resourceMonitorVO.setPlatFileCount("0条");
      resourceMonitorVO.setCodeTableCount("0个");
      resourceMonitorVO.setDataDiskSpace("0KB");
      resourceMonitorVO.setManagePlatDataDiskSpace("0KB");
      resourceMonitorVO.setApplyInterfaceCount(Integer.valueOf(0));
      resourceMonitorVO.setCollectionInterfaceCount(Integer.valueOf(0));
      resourceMonitorVO.setClassifyCount(Integer.valueOf(0));
      resourceMonitorVO.setDataShareCount(Integer.valueOf(0));
      resourceMonitorVO.setSpecialDatabaseCount(Integer.valueOf(0));
      resourceMonitorVO.setTotalFieldCount(Integer.valueOf(0));
      resourceMonitorVO.setTotalTableCount(Integer.valueOf(0));
      resourceMonitorVO.setMetadataCount(Integer.valueOf(0));
    } 
    return ResultEntity.successMessage(resourceMonitorVO);
  }
  
  public ResultEntity<MonitorDataVO> getMonitorData() {
    MonitorDataVO monitorDataVO = new MonitorDataVO();
    monitorDataVO.setDataDiskSpace("0");
    monitorDataVO.setManagePlatDataDiskSpace("0");
    ResourceMonitorVO resultEntity = (ResourceMonitorVO)getResourceMonitor("GB", null).getObj();
    if (resultEntity != null)
      BeanUtils.copyProperties(resultEntity, monitorDataVO); 
    return ResultEntity.successMessage(monitorDataVO);
  }
  
  private String getDiskSpaceStr(Long data, String unit) {
    String result = data + "KB";
    DecimalFormat decimalFormat = new DecimalFormat("#.##");
    if (StringUtils.isEmpty(unit)) {
      if (data.longValue() >= DISKUNIT.intValue() && data.longValue() / DISKUNIT.intValue() < DISKUNIT.intValue()) {
        double mathRet = data.longValue() / DISKUNIT.intValue();
        result = decimalFormat.format(mathRet) + "MB";
      } else if (data.longValue() / DISKUNIT.intValue() >= DISKUNIT.intValue() && data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue() < DISKUNIT.intValue()) {
        double mathRet = data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue();
        result = decimalFormat.format(mathRet) + "GB";
      } else if (data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue() >= DISKUNIT.intValue() && data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue() / DISKUNIT.intValue() < DISKUNIT.intValue()) {
        double mathRet = data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue() / DISKUNIT.intValue();
        result = decimalFormat.format(mathRet) + "TB";
      } 
    } else if (unit.equals("GB")) {
      double mathRet = data.longValue() / DISKUNIT.intValue() / DISKUNIT.intValue();
      result = decimalFormat.format(mathRet) + "GB";
    } 
    return result;
  }
  
  public ResultEntity<List<InterfaceServiceMonitorVO>> getInterfaceServiceMonitorList() {
    List<InterfaceServiceMonitorPO> serviceMonitorPOList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getInterfaceServiceMonitorList();
    List<InterfaceServiceMonitorVO> interfaceServiceMonitorVOS = new ArrayList<>(serviceMonitorPOList.size());
    if (!ObjectUtils.isEmpty(serviceMonitorPOList))
      for (InterfaceServiceMonitorPO interfaceServiceMonitorPO : serviceMonitorPOList) {
        InterfaceServiceMonitorVO interfaceServiceMonitorVO = new InterfaceServiceMonitorVO();
        BeanUtils.copyProperties(interfaceServiceMonitorPO, interfaceServiceMonitorVO);
        interfaceServiceMonitorVOS.add(interfaceServiceMonitorVO);
      }  
    return ResultEntity.successMessage(interfaceServiceMonitorVOS);
  }
  
  public ResultEntity<Map<String, Object>> getTableStatisticsList() {
    Map<String, Object> resultMap = new HashMap<>();
    List<String> notExistEntityIds = new ArrayList<>();
    List<TableStatisticsVO> tableStatisticsVOList = new ArrayList<>();
    List<TableStatisticsPO> tableStatisticsPOList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getTableStatisticsList();
    if (!CollectionUtils.isEmpty(tableStatisticsPOList))
      tableStatisticsVOList = (List<TableStatisticsVO>)tableStatisticsPOList.stream().map(tableStatisticsPO -> {
            TableStatisticsVO tableStatisticsVO = new TableStatisticsVO();
            BeanUtils.copyProperties(tableStatisticsPO, tableStatisticsVO);
            String tableId = tableStatisticsVO.getTableId();
            Integer tablePlatCode = tableStatisticsVO.getTablePlatCode();
            IPlatCommonDataQueryService platCommonDataQueryService = this.tableTypeMap.get(tablePlatCode);
            String tableName = null;
            try {
              tableName = platCommonDataQueryService.getTableNameById(tableId);
              tableId = platCommonDataQueryService.setTableId(tablePlatCode, tableId);
              tableStatisticsVO.setTableName(tableName);
              tableStatisticsVO.setTableId(tableId);
            } catch (Exception e) {
              LogHelper.error("根据表ID获取表名称失败，具体信息为：" + ExceptionUtil.getStackTraceMsg(e));
              notExistEntityIds.add(tableId);
            } 
            return tableStatisticsVO;
          }).collect(Collectors.toList()); 
    resultMap.put("tableStatisticsVOList", tableStatisticsVOList);
    resultMap.put("notExistEntityIds", notExistEntityIds);
    return ResultEntity.successMessage(resultMap);
  }
  
  public String getCode(Integer code) {
    if (code.intValue() == 0)
      return "Collection"; 
    if (code.intValue() == 1)
      return "Manage"; 
    return "Apply";
  }
  
  public ResultEntity<List<DataPushMonitorVo>> getDataPushMonitorList(String platCode, String tokenId) {
    this.quartzJobService.updateDataPushMonitor();
    List<DataPushMonitorPO> dataPushMonitorPOList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getDataPushMonitorList();
    if (dataPushMonitorPOList.isEmpty())
      return ResultEntity.successMessage(Collections.emptyList()); 
    List<DataPushMonitorVo> dataPushMonitorVoList = new ArrayList<>(dataPushMonitorPOList.size());
    for (DataPushMonitorPO dataPushMonitorPO : dataPushMonitorPOList) {
      DataPushMonitorVo dataPushMonitorVo = new DataPushMonitorVo();
      BeanUtils.copyProperties(dataPushMonitorPO, dataPushMonitorVo);
      String interfaceUserName = getInterfaceUserName(dataPushMonitorPO.getInterfaceUserId());
      dataPushMonitorVo.setInterfaceUserName(interfaceUserName);
      dataPushMonitorVoList.add(dataPushMonitorVo);
    } 
    return ResultEntity.successMessage(dataPushMonitorVoList);
  }
  
  public ResultEntity<List<InterfaceInvokeRecordVO>> getInterfaceInvokeRecordList(String platCode, String token, MonitorQueryDTO queryModelDTO) {
    List<InterfaceInvokeRecordPO> interfaceInvokeRecordPOList = null;
    List<InterfaceInvokeRecordVO> interfaceInvokeRecordVOList = null;
    try {
      interfaceInvokeRecordPOList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getInterfaceInvokeRecordList(queryModelDTO);
      if (!CollectionUtils.isEmpty(interfaceInvokeRecordPOList))
        interfaceInvokeRecordVOList = (List<InterfaceInvokeRecordVO>)interfaceInvokeRecordPOList.stream().map(interfaceInvokeRecordPO -> {
              InterfaceInvokeRecordVO interfaceInvokeRecordVO = new InterfaceInvokeRecordVO();
              BeanUtils.copyProperties(interfaceInvokeRecordPO, interfaceInvokeRecordVO);
              Integer interfacePlatCode = interfaceInvokeRecordVO.getInterfacePlatCode();
              IPlatCommonDataQueryService platCommonDataQueryService = this.tableTypeMap.get(interfacePlatCode);
              Long interfaceId = interfaceInvokeRecordVO.getInterfaceId();
              String serviceInterfaceName = platCommonDataQueryService.getInterfaceName(interfacePlatCode, interfaceId);
              interfaceInvokeRecordVO.setInterfaceName(serviceInterfaceName);
              return interfaceInvokeRecordVO;
            }).collect(Collectors.toList()); 
    } catch (Exception e) {
      interfaceInvokeRecordVOList = Collections.emptyList();
      LogHelper.error("获取接口调用记录失败，具体信息为：" + ExceptionUtil.getStackTraceMsg(e));
    } 
    return ResultEntity.successMessage(interfaceInvokeRecordVOList);
  }
  
  public ResultEntity<Map<String, Object>> getInterfaceInvokeDetail(MonitorQueryDTO queryModelDTO, String platCode, String tokenId, Long interfaceId) {
    Map<String, Object> resultMap = new HashMap<>(3);
    List<InterfaceInvokeDetailVO> interfaceInvokeDetailVOList = null;
    Integer interfaceInvokeDetailCount = Integer.valueOf(0);
    Integer totalCount = Integer.valueOf(0);
    try {
      List<InterfaceInvokeDetailPO> interfaceInvokeRecordPOList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getInterfaceInvokeDetailList(queryModelDTO, interfaceId);
      if (!CollectionUtils.isEmpty(interfaceInvokeRecordPOList)) {
        interfaceInvokeDetailVOList = (List<InterfaceInvokeDetailVO>)interfaceInvokeRecordPOList.stream().map(dbInterfaceInvokeDetail -> {
              InterfaceInvokeDetailVO interfaceInvokeDetail = new InterfaceInvokeDetailVO();
              BeanUtils.copyProperties(dbInterfaceInvokeDetail, interfaceInvokeDetail);
              IPlatCommonDataQueryService platCommonDataQueryService = this.tableTypeMap.get(DCConst.PLAT_CODE_MAP.get("Collection"));
              String invokeUserName = platCommonDataQueryService.getInvokeUserName(dbInterfaceInvokeDetail.getInvokeUserId());
              interfaceInvokeDetail.setInvokeUserName(invokeUserName);
              return interfaceInvokeDetail;
            }).collect(Collectors.toList());
        interfaceInvokeDetailCount = Integer.valueOf(interfaceInvokeRecordPOList.size());
      } 
      totalCount = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).selectInterfaceInvokeDetailCount(queryModelDTO, interfaceId);
    } catch (Exception e) {
      CommonLogHelper.consoleError(ExceptionUtil.getStackTraceMsg(e), "查询接口详情失败", DCConst.ServerClientType.RESOURCE);
    } 
    resultMap.put("size", interfaceInvokeDetailCount);
    resultMap.put("totalCount", totalCount);
    resultMap.put("interfaceInvokeDetailVOList", interfaceInvokeDetailVOList);
    return ResultEntity.successMessage(resultMap);
  }
  
  public ResultEntity<List<ServerMonitorVO>> getServerMonitor(String tokenId) {
    List<ServerMonitorPO> serverMonitorPoList = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getServerMonitor();
    List<ServerMonitorVO> serverMonitorVOList = new ArrayList<>();
    if (!CollectionUtils.isEmpty(serverMonitorPoList))
      for (ServerMonitorPO serverMonitorPO : serverMonitorPoList) {
        ServerMonitorVO serverMonitorVO = new ServerMonitorVO();
        BeanUtils.copyProperties(serverMonitorPO, serverMonitorVO);
        serverMonitorVOList.add(serverMonitorVO);
      }  
    return ResultEntity.successMessage(serverMonitorVOList);
  }
  
  public ResultEntity<ServerMonitorVO> saveServerMonitor(ServerMonitorVO serverMonitorVO) {
    if (ObjectUtils.isEmpty(serverMonitorVO))
      return ResultEntity.successMessage(serverMonitorVO); 
    ServerMonitorPO serverMonitorPO = new ServerMonitorPO();
    BeanUtils.copyProperties(serverMonitorVO, serverMonitorPO);
    serverMonitorPO.setId((Long)WorkerId.getNextId(Long.class));
    this.baseDaoImpl.save(serverMonitorPO);
    return ResultEntity.successMessage(serverMonitorVO);
  }
  
  public ResultEntity<ServerMonitorVO> saveAndUpdateServerMonitor(ServerMonitorVO serverMonitorVO) {
    return ResultEntity.successMessage(serverMonitorVO);
  }
  
  public ResultEntity<List<TableTreeVO>> getDataTableTree(TableTreeDTO tableTreeDTO, String tokenId) {
    GetTableTreeDTO getTableTreeDTO = new GetTableTreeDTO();
    BeanUtils.copyProperties(tableTreeDTO, getTableTreeDTO);
    UserInfoDTO userInfoDTO = TokenUtil.getUserInfoByTokenId(tokenId);
    getTableTreeDTO.setUser_id(Long.toString(userInfoDTO.getUserId().longValue()));
    getTableTreeDTO.setOrganization_id(Long.toString(userInfoDTO.getOrganizationId().longValue()));
    List<TableTreeVO> tableTree = this.ilzdpApi.getMonitorDataTableTree(getTableTreeDTO);
    String tableName = tableTreeDTO.getTable_name();
    if (!StringUtils.isEmpty(tableName))
      searchTree(tableName, tableTree); 
    return ResultEntity.successMessage(tableTree);
  }
  
  public ResultEntity<GetDataTableDTO> getDataTableDTOResultEntity(String code, String tokenId) {
    GetDataTableDTO getDataTableDTO = null;
    try {
      ResultEntity<Map<String, Object>> tableStatisticsList = getTableStatisticsList();
      Map<String, Object> tableStatisticsVOList = (Map<String, Object>)tableStatisticsList.getObj();
      ResultEntity<List<WarningRecipientVo>> warningRecipientList = getWarningRecipientList(code, tokenId);
      List<WarningRecipientVo> warningRecipientVoList = (List<WarningRecipientVo>)warningRecipientList.getObj();
      ResourceMonitorPO resourceMonitorPO = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).getResourceMonitor();
      ResultEntity<List<ServerMonitorVO>> serverMonitor = getServerMonitor(tokenId);
      List<ServerMonitorVO> serverMonitorVOList = (List<ServerMonitorVO>)serverMonitor.getObj();
      if (!CollectionUtils.isEmpty(serverMonitorVOList))
        serverMonitorVOList = (List<ServerMonitorVO>)serverMonitorVOList.stream().map(serverMonitorVO -> {
              serverMonitorVO.setPassword("");
              return serverMonitorVO;
            }).collect(Collectors.toList()); 
      getDataTableDTO = new GetDataTableDTO();
      getDataTableDTO.setTableStatisticsVOList(tableStatisticsVOList);
      getDataTableDTO.setServiceSupportSystem(resourceMonitorPO.getBusinessSystemCount());
      getDataTableDTO.setWarningRecipientVoList(warningRecipientVoList);
      getDataTableDTO.setServerMonitorVOList(serverMonitorVOList);
      return ResultEntity.successMessage(getDataTableDTO);
    } catch (Exception e) {
      LogHelper.error("聚合查询结果失败， 具体错误信息为 " + ExceptionUtil.getStackTraceMsg(e));
      return ResultEntity.successMessage(new GetDataTableDTO());
    } 
  }
  
  public ResultEntity<Boolean> deleteDataTableById(String id) {
    TableStatisticsPO tableStatisticsPO = new TableStatisticsPO();
    tableStatisticsPO.setTableId(id);
    tableStatisticsPO.setIsShow(Integer.valueOf(0));
    tableStatisticsPO.setIsDelete(Integer.valueOf(1));
    Boolean flag = Boolean.valueOf(false);
    try {
      Integer integer = ((IMonitoringPlatformDao)ServiceUtil.getMonitoringStatisticsDao(getDefaultCode(), IMonitoringPlatformDao.class)).deleteDataTableById(tableStatisticsPO);
      if (integer.intValue() > 0)
        flag = Boolean.valueOf(true); 
    } catch (Exception e) {
      LogHelper.error("【监控平台-报警配置删除数据表" + id + " 失败】，具体信息为：" + ExceptionUtil.getStackTraceMsg(e));
    } 
    return ResultEntity.successMessage(flag);
  }
  
  public ResultEntity<Boolean> dragDataTable(DragDataTableDTO dragDataTableDTO) {
    List<String> ids = dragDataTableDTO.getIds();
    if (CollectionUtils.isEmpty(ids))
      return ResultEntity.successMessage(Boolean.valueOf(true)); 
    int order = 1;
    for (String id : dragDataTableDTO.getIds()) {
      TableStatisticsPO dataTable = new TableStatisticsPO();
      dataTable.setTableId(id);
      dataTable.setOrder(Integer.valueOf(order++));
      this.iMonitoringPlatformDao.dragDataTable(dataTable);
    } 
    return ResultEntity.successMessage(Boolean.valueOf(true));
  }
  
  private void searchTree(String tableName, List<TableTreeVO> tableTree) {
    if (!CollectionUtils.isEmpty(tableTree)) {
      Iterator<TableTreeVO> iter = tableTree.iterator();
      while (iter.hasNext()) {
        TableTreeVO category = iter.next();
        if (!containsIgnoreCase(category.getName(), tableName)) {
          List<TableTreeVO> childrenCategoryList = category.getChildren();
          if (!CollectionUtils.isEmpty(childrenCategoryList))
            searchTree(tableName, childrenCategoryList); 
          if (CollectionUtils.isEmpty(category.getChildren()))
            iter.remove(); 
        } 
      } 
    } 
  }
  
  private boolean containsIgnoreCase(CharSequence str, CharSequence testStr) {
    if (null == str)
      return (null == testStr); 
    return str.toString().toLowerCase().contains(testStr.toString().toLowerCase());
  }
  
  public String getUserName(Long userId, String token, QueryModelDTO queryModelDTO) {
    String userName = "";
    ResultEntity<UserVO> userVOById = this.coreClient.getUserVOById(userId, token);
    try {
      ResultEntity<UserVO> userVOResultEntity = this.coreClient.getUserVOById(userId, token);
      UserVO userVO = (UserVO)userVOResultEntity.getObj();
      if (!ObjectUtils.isEmpty(userVO))
        userName = userVO.getUserName(); 
      return userName;
    } catch (Exception e) {
      LogHelper.error("远程调用【coreClient.getUserList()失败】，具体错误信息，" + ExceptionUtil.getStackTraceMsg(e));
      return userName;
    } 
  }
  
  private String getInterfaceUserName(Long interfaceUserId) {
    ResultEntity<List<DataPushMonitorVo>> dataPushMonitorVo1 = null;
    try {
      dataPushMonitorVo1 = this.dataApplyClient.getDataPushMonitorVo(String.valueOf(COUNT));
      List<DataPushMonitorVo> pushMonitorVo1Obj = (List<DataPushMonitorVo>)dataPushMonitorVo1.getObj();
      if (CollectionUtils.isEmpty(pushMonitorVo1Obj))
        return emptyString(); 
      for (DataPushMonitorVo dataPushMonitorVo : pushMonitorVo1Obj) {
        if (dataPushMonitorVo.getInterfaceUserId().intValue() == interfaceUserId.intValue())
          return dataPushMonitorVo.getInterfaceUserCnName(); 
      } 
    } catch (Exception e) {
      LogHelper.error("远程调用【应用平台推送用户失败】,具体错误信息：" + e.getMessage());
    } 
    return emptyString();
  }
  
  @PostConstruct
  public void init() {
    initTypeMap();
  }
  
  public void initTypeMap() {
    this.tableTypeMap = new HashMap<>();
    Map<String, IPlatCommonDataQueryService> beansOfType = this.applicationContext.getBeansOfType(IPlatCommonDataQueryService.class);
    for (IPlatCommonDataQueryService platService : beansOfType.values()) {
      String defaultCode = platService.getDefaultCode();
      Integer platInt = (Integer)DCConst.PLAT_CODE_MAP.get(defaultCode);
      if (platInt != null)
        this.tableTypeMap.put(platInt, platService); 
    } 
  }
  
  public String emptyString() {
    return "";
  }
  
  private void logSystemInfo(String msg, String tokenId, String platCode) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_SYSTEM);
    logDTO.setModule_code(HeaderInterceptor.getModuleCode());
    logDTO.setLogType(0);
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
  
  private void logSystemError(String msg, String tokenId, String platCode) {
    CommonLogDTO logDTO = new CommonLogDTO();
    logDTO.setPlatCode(platCode);
    logDTO.setTokenId(tokenId);
    logDTO.setLoggerInformation(msg);
    logDTO.setLogLevel(FrameConst.Log.LOG_LEVEL_ERROR);
    logDTO.setLogType(0);
    RabbitMQUtil.publish("DC.Standard.log", logDTO);
  }
}
